==> react-input-enhancements-0.3.4.tgz: package/lib/utils/getComputedStyle.js <==
// Source: https://github.com/jonathantneal/Polyfills-for-IE8/blob/master/getComputedStyle.js

'use strict';

!('getComputedStyle' in window) && (window.getComputedStyle = (function (window) {
  function getPixelSize(element, style, property, fontSize) {
    var sizeWithSuffix = style[property];
    var size = parseFloat(sizeWithSuffix);
    var suffix = sizeWithSuffix.split(/\d/)[0];
    var rootSize = undefined;

    fontSize = fontSize != null ? fontSize : /%|em/.test(suffix) && element.parentElement ? getPixelSize(element.parentElement, element.parentElement.currentStyle, 'fontSize', null) : 16;
    rootSize = property == 'fontSize' ? fontSize : /width/i.test(property) ? element.clientWidth : element.clientHeight;

    return suffix == 'em' ? size * fontSize : suffix == 'in' ? size * 96 : suffix == 'pt' ? size * 96 / 72 : suffix == '%' ? size / 100 * rootSize : size;
  }

  function setShortStyleProperty(style, property) {
    var borderSuffix = property == 'border' ? 'Width' : '';
    var t = property + 'Top' + borderSuffix;
    var r = property + 'Right' + borderSuffix;
    var b = property + 'Bottom' + borderSuffix;
    var l = property + 'Left' + borderSuffix;

    style[property] = (style[t] == style[r] == style[b] == style[l] ? [style[t]] : style[t] == style[b] && style[l] == style[r] ? [style[t], style[r]] : style[l] == style[r] ? [style[t], style[r], style[b]] : [style[t], style[r], style[b], style[l]]).join(' ');
  }

  function CSSStyleDeclaration(element) {
    var currentStyle = element.currentStyle;
    var style = this;
    var fontSize = getPixelSize(element, currentStyle, 'fontSize', null);

    for (var property in currentStyle) {
      if (/width|height|margin.|padding.|border.+W/.test(property) && style[property] !== 'auto') {
        style[property] = getPixelSize(element, currentStyle, property, fontSize) + 'px';
      } else if (property === 'styleFloat') {
        style['float'] = currentStyle[property];
      } else {
        style[property] = currentStyle[property];
      }
    }

    setShortStyleProperty(style, 'margin');
    setShortStyleProperty(style, 'padding');
    setShortStyleProperty(style, 'border');

    style.fontSize = fontSize + 'px';

    return style;
  }

  CSSStyleDeclaration.prototype = {
    constructor: CSSStyleDeclaration,
    getPropertyPriority: function getPropertyPriority() {},
    getPropertyValue: function getPropertyValue(prop) {
      return window[prop] || '';
    },
    item: function item() {},
    removeProperty: function removeProperty() {},
    setProperty: function setProperty() {},
    getPropertyCSSValue: function getPropertyCSSValue() {}
  };

  function getComputedStyle(element) {
    return new CSSStyleDeclaration(element);
  }

  return getComputedStyle;
})(window));

==> react-input-enhancements-0.7.6.tgz: package/lib/utils/getComputedStyle.js <==
'use strict';

// Source: https://github.com/jonathantneal/Polyfills-for-IE8/blob/master/getComputedStyle.js

typeof window !== 'undefined' && !('getComputedStyle' in window) && (window.getComputedStyle = function (window) {
  function getPixelSize(element, style, property, fontSize) {
    var sizeWithSuffix = style[property];
    var size = parseFloat(sizeWithSuffix);
    var suffix = sizeWithSuffix.split(/\d/)[0];
    var rootSize = void 0;

    fontSize = fontSize != null ? fontSize : /%|em/.test(suffix) && element.parentElement ? getPixelSize(element.parentElement, element.parentElement.currentStyle, 'fontSize', null) : 16;
    rootSize = property === 'fontSize' ? fontSize : /width/i.test(property) ? element.clientWidth : element.clientHeight;

    return suffix === 'em' ? size * fontSize : suffix === 'in' ? size * 96 : suffix === 'pt' ? size * 96 / 72 : suffix === '%' ? size / 100 * rootSize : size;
  }

  function setShortStyleProperty(style, property) {
    var borderSuffix = property === 'border' ? 'Width' : '';
    var t = property + 'Top' + borderSuffix;
    var r = property + 'Right' + borderSuffix;
    var b = property + 'Bottom' + borderSuffix;
    var l = property + 'Left' + borderSuffix;

    style[property] = (style[t] === style[r] === style[b] === style[l] ? [style[t]] : style[t] === style[b] && style[l] === style[r] ? [style[t], style[r]] : style[l] === style[r] ? [style[t], style[r], style[b]] : [style[t], style[r], style[b], style[l]]).join(' ');
  }

  function CSSStyleDeclaration(element) {
    var currentStyle = element.currentStyle;
    var style = this;
    var fontSize = getPixelSize(element, currentStyle, 'fontSize', null);

    for (var property in currentStyle) {
      if (/width|height|margin.|padding.|border.+W/.test(property) && style[property] !== 'auto') {
        style[property] = getPixelSize(element, currentStyle, property, fontSize) + 'px';
      } else if (property === 'styleFloat') {
        style['float'] = currentStyle[property];
      } else {
        style[property] = currentStyle[property];
      }
    }

    setShortStyleProperty(style, 'margin');
    setShortStyleProperty(style, 'padding');
    setShortStyleProperty(style, 'border');

    style.fontSize = fontSize + 'px';

    return style;
  }

  CSSStyleDeclaration.prototype = {
    constructor: CSSStyleDeclaration,
    getPropertyPriority: function getPropertyPriority() {},
    getPropertyValue: function getPropertyValue(prop) {
      return window[prop] || '';
    },
    item: function item() {},
    removeProperty: function removeProperty() {},
    setProperty: function setProperty() {},
    getPropertyCSSValue: function getPropertyCSSValue() {}
  };

  function getComputedStyle(element) {
    return new CSSStyleDeclaration(element);
  }

  return getComputedStyle;
}(window));
